[![Coverage Status](https://coveralls.io/repos/github/Chik-Network/klvm/badge.svg?branch=main)](https://coveralls.io/github/Chik-Network/klvm?branch=main)

This is the in-development version of a LISP-like language for encumbering and releasing funds with smart-contract capabilities.

See docs/klvm.org or https://chiklisp.com/ for more info.


Testing
=======

    $ python3 -m venv venv
    $ . ./venv/bin/activate
    $ pip install -e '.[dev]'
    $ pytest tests

